@@ -1,7 +1,7 @@
 import pathlib
 import configparser
 
-__version__ = '0.13.0'
+__version__ = '0.17.2'
 
 # Load the configuration settings.
 HERE = pathlib.Path(__file__).parent.resolve()
@@ -44,4 +44,7 @@ from asilib.analysis.equal_area import equal_area
 # Imager implementation functions and classes.
 from asilib.imager import Imager
 from asilib.conjunction import Conjunction
-from asilib.array.themis import themis, themis_info
+from asilib.asi.themis import themis, themis_info, themis_skymap
+from asilib.asi.rego import rego, rego_info, rego_skymap
+
+__all__ = ['Imager', 'Conjunction']  # So Sphinx shortens the name. See https://stackoverflow.com/a/66743762
\ No newline at end of file
